MethodChannelMultiScreenPresentation class

Implémentation basée sur MethodChannel + EventChannel.

Convention des canaux (doit correspondre au code natif de chaque plateforme) :

  • Channel de commandes : "multi_screen_presentation"
  • Channel d'évènements : "multi_screen_presentation/events"

Le natif fait le pont entre le moteur Flutter principal et le(s) moteur(s) Flutter secondaire(s) ouverts dans les fenêtres de présentation, sur les canaux "multi_screen_presentation/window/id".

Inheritance

Properties

eventChannel EventChannel
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
rawEvents Stream<Map<String, dynamic>>
Flux d'évènements génériques venant du natif : changements de mode, fermeture de fenêtre, changement de liste d'écrans (branchement/ débranchement à chaud), données remontées depuis la fenêtre secondaire.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeWindow(String windowId) Future<void>
override
getScreens() Future<List<ScreenInfo>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWindow(WindowOptions options) Future<String>
override
sendData(String windowId, Map<String, dynamic> data) Future<void>
Envoie des données JSON-compatibles depuis l'app principale vers la fenêtre secondaire (peu importe si celle-ci est en liveFlutterEngine ou manual).
override
setWindowAlwaysOnTop(String windowId, bool alwaysOnTop) Future<void>
override
setWindowBounds(String windowId, {required int x, required int y, required int width, required int height}) Future<void>
override
setWindowFullscreen(String windowId, bool fullscreen) Future<void>
override
setWindowIcon(String windowId, String? iconPath) Future<void>
override
setWindowMode(String windowId, WindowMode mode) Future<void>
override
setWindowOpacity(String windowId, double opacity) Future<void>
override
setWindowPosition(String windowId, int x, int y) Future<void>
override
setWindowResizable(String windowId, bool resizable) Future<void>
override
setWindowSize(String windowId, int width, int height) Future<void>
override
setWindowTitle(String windowId, String title) Future<void>
override
setWindowVisible(String windowId, bool visible) Future<void>
override
toggleWindowMode(String windowId) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited