MultiScreenPresentationPlatform class
abstract
Inheritance
Object
PlatformInterface
MultiScreenPresentationPlatform
Implementers
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
rawEvents
→ Stream <Map <String , dynamic > >
Flux d'évènements génériques venant du natif : changements de mode,
fermeture de fenêtre, changement de liste d'écrans (branchement/
débranchement à chaud), données remontées depuis la fenêtre secondaire.
no setter
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
closeWindow (String windowId )
→ Future <void >
getScreens ()
→ Future <List <ScreenInfo > >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWindow (WindowOptions options )
→ Future <String >
sendData (String windowId , Map <String , dynamic > data )
→ Future <void >
Envoie des données JSON-compatibles depuis l'app principale vers la
fenêtre secondaire (peu importe si celle-ci est en liveFlutterEngine
ou manual).
setWindowAlwaysOnTop (String windowId , bool alwaysOnTop )
→ Future <void >
setWindowBounds (String windowId , {required int x , required int y , required int width , required int height })
→ Future <void >
setWindowFullscreen (String windowId , bool fullscreen )
→ Future <void >
setWindowIcon (String windowId , String ? iconPath )
→ Future <void >
setWindowMode (String windowId , WindowMode mode )
→ Future <void >
setWindowOpacity (String windowId , double opacity )
→ Future <void >
setWindowPosition (String windowId , int x , int y )
→ Future <void >
setWindowResizable (String windowId , bool resizable )
→ Future <void >
setWindowSize (String windowId , int width , int height )
→ Future <void >
setWindowTitle (String windowId , String title )
→ Future <void >
setWindowVisible (String windowId , bool visible )
→ Future <void >
toggleWindowMode (String windowId )
→ Future <void >
toString ()
→ String
A string representation of this object.
inherited
multi_screen_presentation 1.0.9